IterableMathDoubleNullable extension

on

Properties

highest → double?

Available on Iterable<double?>, provided by the IterableMathDoubleNullable extension

Returns the highest value in the list.
no setter
lowest → double?

Available on Iterable<double?>, provided by the IterableMathDoubleNullable extension

Returns the lowest value in the list.
no setter

Methods

absSum([bool invert = false]) → double

Available on Iterable<double?>, provided by the IterableMathDoubleNullable extension

Returns the sum of the absolute values in the iterable.
sum() → double

Available on Iterable<double?>, provided by the IterableMathDoubleNullable extension

Returns the sum of the values in the iterable.