IterableMathNumNullable extension

Extends Iterable<num> with additional basic methods.

on

Properties

highest → num?

Available on Iterable<num?>, provided by the IterableMathNumNullable extension

Returns the highest value in the list.
no setter
lowest → num?

Available on Iterable<num?>, provided by the IterableMathNumNullable extension

Returns the lowest value in the list.
no setter

Methods

absSum([bool invert = false]) → num

Available on Iterable<num?>, provided by the IterableMathNumNullable extension

Returns the sum of the absolute values in the iterable.
sum() → num

Available on Iterable<num?>, provided by the IterableMathNumNullable extension

Returns the sum of the values in the iterable.